# Composer

A Composer of Tables.

```bash
pip install composer
```

## Usage

See [Colab Notebook](https://colab.research.google.com/drive/1g3V-ZER91-KUnGzOv4B2t28URPTYC60S) for demo.


## ToDo

- `CT.drop()` method for dropping columns/rows
- `CT.iloc[1:3, 2:5]` select/modify cell/row/columns[^1]

[^1]: Refer to [link1](https://stackoverflow.com/questions/26811712/how-can-a-function-accept-a-colon-range-operator-as-an-argument-in-python) and [link2](https://iter01.com/367485.html) for potential implementation.
